CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Misc
 * Documentation
 * Learning resources
 * Maintainers


INTRODUCTION
------------

This is a bootstrap base theme with a goal to support full frontend Drupal theme
development workflow from start to finish.

## NOTE

For up-to-date documentation please visit
https://www.drupal.org/docs/contributed-themes/bs-base.


REQUIREMENTS
------------

This theme requires the following modules:

 * BS Lib (https://drupal.org/project/bs_lib)


INSTALLATION
------------

 * Install and enable bs_lib module first. See [Installing Drupal 8 Modules](https://www.drupal.org/docs/8/extending-drupal-8/installing-drupal-8-modules)
   page for further information.
 * Install as you would normally install a contributed Drupal theme. See
   [Installing Themes](https://www.drupal.org/docs/8/extending-drupal-8/installing-themes)
   for further information.


CONFIGURATION
-------------

This theme supports various configuration options on the theme settings page in
the 'BS Bootstrap' section.

## Navigation bar toggler

In order to use [Bootstrap navigation bar toggler](https://getbootstrap.com/docs/4.0/components/navbar/#toggler)
you need to add 'Navigation bar toggler' block to some region. Usually you will
add this block to 'Navigation Second' region, but it is possible to use some
other region and tweak CSS layout rules if needed. However you can not add this
block to 'Navigation Bar' region because this is the region which toggle button
will collapse/expand by default.


## Navigation Bar menu

All menu blocks that are added to 'Navigation Bar' region will be converted to
[Navbar Bootstrap control](https://getbootstrap.com/docs/4.0/components/navbar/).
This is the only region that currently support navbar control.


## Header navigation container types

For the header top and navigation bar header type we are supporting two
container types fluid (default) and fixed. You can change this option on  theme
settings page.

## Navbar types

This theme supports two navigation bar types in theme settings option:
- 'Second level dropdown', is good when you need just two menu levels where 1st
  menu level will be ordinary navigation items layout horizontally and 2nd menu
  level items will be in dropdown menu.
- 'Second level horizontal', when you need 3 menu level support in navigation
  bar. 1st and 2nd level will be standard menu items layout horizontally and 3th
  menu level items will be in dropdown menu.


## Navbar off-canvas support (Experimental)

This theme can also support off-canvas navigation with a help of jasny/bootstrap
library. For more info visit [jansy/bootstrap examples](http://www.jasny.net/bootstrap/examples/navmenu)
page.

You first need to install jasny-bootstrap library as explained in bs_lib
README.md file - be sure to install forked version which is ported to Bootstrap
4.

Then in theme settings enable 'Navbar off-canvas type'.

__NOTES__
- Type `reveal` is currently not supported.
- Position `left` is not fully supported and tested. Position `top` and `bottom`
  are not supported at all for now.


## Language block settings

This theme supports two language block types in theme settings:
- 'Links' (default)
- 'Dropdown'

Language block type `links` is a standard Drupal language links rendering.

Language block type `dropdown` use Bootstrap dropdown button to render language
links.
You can override `links--dropdown-language-block.html.twig` template in your
custom theme to additionally change HTMl code of dropdown language block.

You can also control title of language link with 'Language block title' option:
- 'Label' - default, language name
- 'Language code' - use language code for link title


## Custom Forms

Enable 'Custom Bootstrap forms support' option in theme setting in order to use
[Bootstrap custom forms](https://v4-alpha.getbootstrap.com/components/forms/#custom-forms).

Checkboxes and radios, select menu and file browser custom forms are all
supported.


Documentation
-------------

For the most up-to-date documentation, please visit https://www.drupal.org/docs/8/themes/bs-base.

For support, visit the #bs_base channel on Slack at https://drupal.slack.com/archives/C07M3C0RATC.


### Install

We need some global dependencies: node, npm, and gulp-cli.

For node and npm it is recommended to use nvm to install and manage different
node versions on your system. For installation of nvm check https://github.com/nvm-sh/nvm#installing-and-updating.

Current version of bs_base requires node 18.

To install gulp-cli execute:
```
$ npm install -g gulp-cli
```

Instead of npm you can use pnpm installer which is much faster and requires
less resources on your system. Check https://pnpm.io/installation for more
details how to install pnpm on your system.

After all dependencies are installed run:
```
$ drush bs-tc bs_base custom_theme Custom Custom
```

Which will create a new custom_theme from a parent bs_base theme.


### Standard stuff

In your custom theme execute next commands:

Download all dependencies and build CSS files.
```
$ npm run build-css
```

Build CSS with
```
$ npx gulp sass
```

Use watch task if you like
```
$ npx gulp watch
```

Just build everything for production
```
$ npx gulp
```

Specific Gulp task we currently offers are:

- npx gulp sass
- npx gulp sass:dev
- npx gulp sass:lint
- npx gulp clean:css
- npx gulp bootstrap:js
- npx gulp bootstrap:js:dev
- npx gulp clean:bootstrap

Watchers:

- npx gulp watch
- npx gulp watch-dev

Run all tasks:

- npx gulp
- npx gulp prod
- npx gulp dev


### gulp-options.json

Various config variables we use for gulp build. Do note that if paths
are relative they are relative from position of gulpfile.js.


### Browser support explained

Defined in `.browserlistsrc` file in theme root folder:

```
# Browsers that we support

# > 0.5%, last 2 versions, Firefox ESR, not dead
defaults
```

More info on https://github.com/browserslist/browserslist.


Learning resources
------------------

- https://github.com/Famolus/awesome-sass
  Curated list of awesome Sass and SCSS frameworks, libraries, style guides,
  articles, and resources.


MAINTAINERS
-----------

Current maintainers:
 * Ivica Puljic (pivica) - https://www.drupal.org/u/pivica

This project has been sponsored by:
 * MD Systems - https://www.drupal.org/md-systems
   Drupal core and contributed development.
   MD Systems is working for small start-ups as well as large Swiss corporations
   with international, multilingual websites.
